@@ -1,7 +1,5 @@
-"""
-    The package description.
+"""Support migrations for Peewee ORM."""
 
-"""
 import datetime as dt
 import logging
 
@@ -11,7 +9,7 @@ import peewee as pw
 # Package information
 # ===================
 
-__version__ = "1.4.3"
+__version__ = "1.4.5"
 __project__ = "peewee_migrate"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
@@ -23,13 +21,12 @@ LOGGER.setLevel(logging.INFO)
 
 
 class MigrateHistory(pw.Model):
-
     """Presents the migrations in database."""
 
     name = pw.CharField()
     migrated_at = pw.DateTimeField(default=dt.datetime.utcnow)
 
-    def __unicode__(self):
+    def __unicode__(self) -> str:
         """String representation."""
         return self.name
 
